% 0.84 micron spheres
close all;
centroids = load('0.84 micron in water 010610-0840 SCW.txt');
pixelSize = 7.4E-6 / 40;
frameRate = 20;

trackingParameters = struct();
trackingParameters.good = 20;
trackingParameters.mem = 0;
trackingParameters.dim = 2;
trackingParameters.quiet = 0;

d    = 0.84e-6;             % particle diameter in meters
eta  = 1.0e-3;              % viscosity of water in SI units (Pascal-seconds) at 293 K
kB   = 1.38e-23;            % Boltzmann constant
T    = 293;                 % Temperature in degrees Kelvin

theoreticalDiffusionCoefficient    = kB * T / (3 * pi * eta * d)

trajectories = track(centroids, 10, trackingParameters);

numberOfParticles = max(trajectories(:,4));
fprintf(['Tracked ' num2str(numberOfParticles) ' particles.\n']);

results = CalculateDiffusionCoefficientFromTrajectories(trajectories, pixelSize, frameRate);

percentError = (results.diffusionCoefficient - theoreticalDiffusionCoefficient) / theoreticalDiffusionCoefficient;
sdError = (results.diffusionCoefficient - theoreticalDiffusionCoefficient) / results.diffusionCoefficientUncertainty;

fprintf(['Particle diameter: ' num2str(d) '\n']);
fprintf(['Solvent viscosity ' num2str(eta) '\n']);
fprintf(['Theoretical value of diffusion coefficient: ' num2str(theoreticalDiffusionCoefficient) '\n']);
fprintf(['Estimated value of diffusion coefficient from particle tracks: ' num2str(results.diffusionCoefficient) '\n']);
fprintf(['Percent error: ' num2str(percentError) ' = ' num2str(sdError) 'standard devistions\n']);
fprintf(['Standard error of estimated diffusion coefficient: ' num2str(results.diffusionCoefficientUncertainty) '\n']);

% Stability
centroids = load('1micron dry RhB 10fps 010610 SFN.txt');
pixelSize = 7.4E-6 / 40;
frameRate = 20;

trackingParameters = struct();
trackingParameters.good = 20;
trackingParameters.mem = 0;
trackingParameters.dim = 2;
trackingParameters.quiet = 0;

trajectories = track(centroids, 10, trackingParameters);

particle1 = trajectories(trajectories(:,4)==1,:);
particle2 = trajectories(trajectories(:,4)==2,:);

sumTrajectory = particle1;
sumTrajectory(:, 1:2) = sumTrajectory(:, 1:2) + particle2(:, 1:2);
sumTrajectory(:, 1:2) = sumTrajectory(:, 1:2) ./ 2;
differenceTrajectory = particle2;
differenceTrajectory(:, 1:2) = differenceTrajectory(:, 1:2) - particle1(:, 1:2);
differenceTrajectory(:, 1:2) = differenceTrajectory(:, 1:2) ./ 2;

sumAndDifference = vertcat(sumTrajectory, differenceTrajectory);

results = CalculateDiffusionCoefficientFromTrajectories(sumAndDifference, pixelSize, frameRate);

